import { hooksErrHandler } from '../hooks/types';
export interface useAVToggleResult {
    /**
     * true if unmuted and vice versa
     */
    isLocalAudioEnabled: boolean;
    isLocalVideoEnabled: boolean;
    /**
     * use this function to toggle audio state, the function will only be present if the user
     * has permission to unmute audio
     */
    toggleAudio?: () => void;
    /**
     * use this function to toggle video state, the function will only be present if the user
     * has permission to unmute video
     */
    toggleVideo?: () => void;
}
/**
 * Use this hook to implement mute/unmute for audio and video.
 * isAllowedToPublish can be used to decide whether to show the toggle buttons in the UI.
 * @param handleError to handle any error during toggle of audio/video
 */
export declare const useAVToggle: (handleError?: hooksErrHandler) => useAVToggleResult;
